﻿// @EXPECTED_RESULTS@: CORRECT
//#define OUTPUT_DEBUG
//  > "C:\Users\b.pat-el\Documents\T.NET\BAPC 2015\Museum\template\testcases\sample.out"

using System;
using System.Collections.Generic;

namespace CSharpSolutions {
	public class Museum {
		public const int MIN_L = 1;
		public const int MIN_W = 1;
		public const int MAX_L = 100;
		public const int MAX_W = 100;
		public const double MIN_X = .1d;
		public const double MIN_Y = .1d;
		public const double MIN_SW = .1d;
		public const double WALL_D = .1d;

		public static void DoMuseum() {
#if CASECOUNT_GIVEN
			string testcases = Console.In.ReadLine();
			int cases = int.Parse(testcases);
			if (cases < 0 || cases > 100) throw new ArgumentOutOfRangeException("Input error: Wrong number of test cases: '" + cases + "'");
			while (cases-- > 0) solve();
#else
			while (solve()) ;
#endif // CASECOUNT_GIVEN
		}

		static int l, w;
		static double x, y, sw;
		static line[] pedestal;
		static int gn;
#if CASECOUNT_GIVEN
		private static void solve() {
			string dimensions = Console.In.ReadLine();
#else
		private static bool solve() {
			string dimensions = Console.In.ReadLine();
			if (dimensions == null) return false;
#endif
			string[] split = dimensions.Split(' ');
			if (split.Length != 2) throw new ArgumentException("Input error: Expected 2 elements on this line, found " + split.Length + " instead.");
			//A line containing two integers l and w, the length and width of the room in meters, respectively.
			if (!int.TryParse(split[0], out l))
				throw new ArgumentException("Input error: Could not parse '" + l + "' as int.");
			if (!int.TryParse(split[1], out w))
				throw new ArgumentException("Input error: Could not parse '" + w + "' as int.");

			if (l < MIN_L || l > MAX_L) throw new ArgumentException("Input error: l not within given limits (l = " + l + ")");
			if (w < MIN_W || w > MAX_W) throw new ArgumentException("Input error: w not within given limits (w = " + w + ")");

			// A line containing three floating point numbers x, y and ws, the x-coordinates, y - coordinates and width of the square pedestal all in meters.
			string pedestalIn = Console.In.ReadLine();
			split = pedestalIn.Split(' ');
			if (split.Length != 3) throw new ArgumentException("Input error: Expected 3 elements on this line, found " + split.Length + " instead.");

			if (!double.TryParse(split[0], out x))
				throw new ArgumentException("Input error: Could not parse '" + x + "' as double.");
			if (!double.TryParse(split[1], out y))
				throw new ArgumentException("Input error: Could not parse '" + y + "' as double.");
			if (!double.TryParse(split[2], out sw))
				throw new ArgumentException("Input error: Could not parse '" + sw + "' as double.");

			if (x < MIN_X || x > l - WALL_D) throw new ArgumentException("Input error: x not within given limits (x = " + x + ")");
			if (y < MIN_Y || y > w - WALL_D) throw new ArgumentException("Input error: y not within given limits (y = " + y + ")");
			if (sw < MIN_SW || sw + x > l - WALL_D || sw + y > w - WALL_D) throw new ArgumentException("Input error: pedestal is too large (sw = " + sw + ")");
			// Convert pedestal into 4 lines
			pedestal = new line[4];
			pedestal[0] = new line(x, y, x + sw, y); // Top
			pedestal[1] = new line(x + sw, y, x + sw, y + sw); // Right
			pedestal[2] = new line(x, y + sw, x + sw, y + sw); // Bottom
			pedestal[3] = new line(x, y, x, y + sw); // Left
			gn = 0;

			var result = lessNaiveAndSlow();
			var sanity = triangleCount();
			// Sanity check
			if (result > sanity)
				throw new Exception("Sanity check failed! More triangles were found than possible! " + result + " found, vs " + sanity + " theoretical.");
			Console.WriteLine(result);

#if CASECOUNT_GIVEN
			return;
#else
			return true;
#endif
		}

		private static int triangleCount() {
			int n = 2 * (l + w);

			// Number of triangles is	(n) =     n!
			//							(3) = 3!(n - 3!)
			var pillarsTop = l + 1;
			var pillarsRight = w + 1;
			var pillarsDown = l + 1;
			var pillarsLeft = w + 1;

			int triangles = (n * (n - 1) * (n - 2)) / 6;
			// Echter, dat geldt alleen voor als de punten willekeurig liggen. maar dat is hier niet het geval
			// Dus, daar moet je de hoeveelheid driehoeken van af halen die niet gevormd kunnen worden doordat ze op één lijn liggen
			if (l > 2)
				triangles -= ((pillarsTop * (pillarsTop - 1) * (pillarsTop - 2)) / 6) * 2; // Top en bottom
			if (w > 2)
				triangles -= ((pillarsLeft * (pillarsLeft - 1) * (pillarsLeft - 2)) / 6) * 2; // Left en right

			return triangles;
		}

		private static int lessNaiveAndSlow() {
			var pillars = getPillars();
			int count = 0;
			for (var i = 0; i < pillars.Count; i++) {
				var p1 = pillars[i];
				for (var j = i + 1; j < pillars.Count; j++) {
					var p2 = pillars[j];
					if (p1.x != p2.x || p1.y != p2.y) {
						var l = new line(p1.x, p1.y, p2.x, p2.y);
						if (intersectsPedestal(l)) continue;
					}

					for (var k = j + 1; k < pillars.Count; k++) {
						var p3 = pillars[k];
						if (p1.x == p2.x && p2.x == p3.x) continue;
						if (p1.y == p2.y && p2.y == p3.y) continue;

						if (p1.x != p3.x || p1.y != p3.y) {
							var l = new line(p1.x, p1.y, p3.x, p3.y);
							if (intersectsPedestal(l)) continue;
						}

						if (p2.x != p3.x || p2.y != p3.y) {
							var l = new line(p2.x, p2.y, p3.x, p3.y);
							if (intersectsPedestal(l)) continue;
						}
						++count;
					}
				}
			}
			return count;
		}

		private static List<point> getPillars() {
			var result = new List<point>();
			foreach (var p in getPillar())
				result.Add(p);
			return result;
		}

		private static IEnumerable<point> getPillar() {
			foreach (point p in getPillarTop())
				yield return p;
			foreach (point p in getPillarRight())
				yield return p;
			foreach (point p in getPillarDown())
				yield return p;
			foreach (point p in getPillarLeft())
				yield return p;
		}

		private static IEnumerable<point> getPillarTop() {
			for (int i = 0; i <= l; i++)
				yield return new point { x = i, y = 0, n = gn++ };
		}

		private static IEnumerable<point> getPillarRight() {
			for (int i = 1; i <= w; i++)
				yield return new point { x = l, y = i, n = gn++ };
		}

		private static IEnumerable<point> getPillarDown() {
			for (int i = 0; i <= l - 1; i++)
				yield return new point { x = i, y = w, n = gn++ };
		}

		private static IEnumerable<point> getPillarLeft() {
			for (int i = 1; i <= w - 1; i++)
				yield return new point { x = 0, y = i, n = gn++ };
		}

		private static bool intersectsPedestal(line l) {
			return intersects(l, pedestal[0]) || intersects(l, pedestal[1]) || intersects(l, pedestal[2]) || intersects(l, pedestal[3]);
		}

		private static bool intersects(line l1, line l2) {
			double d = (l2.y2 - l2.y1) * (l1.x2 - l1.x1) - (l2.x2 - l2.x1) * (l1.y2 - l1.y1);
			double n_a = (l2.x2 - l2.x1) * (l1.y1 - l2.y1) - (l2.y2 - l2.y1) * (l1.x1 - l2.x1);
			double n_b = (l1.x2 - l1.x1) * (l1.y1 - l2.y1) - (l1.y2 - l1.y1) * (l1.x1 - l2.x1);

			if (Math.Abs(d) <= 0.0001d)
				return false;

			double ua = n_a / d;
			double ub = n_b / d;

			if (ua >= 0d && ua <= 1d && ub >= 0d && ub <= 1d) return true;
			return false;
		}

		public class line {
			public double x1, y1, x2, y2;
			public line(double x1, double y1, double x2, double y2) { this.x1 = x1; this.y1 = y1; this.x2 = x2; this.y2 = y2; }
		}

		public class point {
			public int x, y, n;
		}
	}
}
