/*
Solution to the BAPC Map Colouring exercise by Johan van Rooij

// @EXPECTED_RESULTS@: CORRECT

Worse case running time: O(4^n m)
Actual running time: much faster!
Memory usage: O(n + m)

*/

// deze is nog incorrect op een aantal anti stijns!

#include <iostream>
#include <memory>
#include <vector>
using namespace std;

struct Vertex
{
	Vertex() 
		: colour( -1 ) 
	{ 
		reset();
	}

	void reset()
	{
		colour = -1;
		for ( int i = 0; i < 4; ++i ) 
			colour_possible[ i ] = true; 
	}

	int colour; // -1 if no colour, otherwise colour 0, 1, 2, or 3.
	bool colour_possible[4];
	std::vector<int> neighbours;
};

std::vector<Vertex> readInput()
{
	int n, m; cin >> n >> m;
	std::vector<Vertex> input( n );
	for ( int i = 0; i < m; ++i )
	{
		int v1, v2; cin >> v1 >> v2;
		input[ v1 ].neighbours.push_back( v2 );
		input[ v2 ].neighbours.push_back( v1 );
	}
	return input;
}

struct Modification 
{ 
	virtual void undo() = 0;
};

struct ReduceDomain : public Modification
{
	ReduceDomain( Vertex* pVertex, int colour )
		: mpVertex( pVertex ), mColour( colour ), mPreviouslyPossible( pVertex->colour_possible[ colour ] )
	{
		mpVertex->colour_possible[mColour] = false;
	}

	void undo() override
	{
		mpVertex->colour_possible[mColour] = mPreviouslyPossible;
	}

	Vertex* mpVertex;
	int mColour;
	bool mPreviouslyPossible;
};

struct FixColour : public Modification
{
	FixColour( Vertex* pVertex, int colour )
		: mpVertex( pVertex )
	{
		// save undo information
		for ( int i = 0; i < 4; ++i )
			mUndo_colour_possible[i] = mpVertex->colour_possible[i];

		// set colour
		mpVertex->colour = colour;
		for ( int i = 0; i < 4; ++i )
			mpVertex->colour_possible[i] = ( i == colour );
	}
	void undo() override
	{
		mpVertex->colour = -1;
		for ( int i = 0; i < 4; ++i )
			mpVertex->colour_possible[i] = mUndo_colour_possible[i];
	}

	Vertex* mpVertex;
	bool mUndo_colour_possible[4];
};

std::vector<std::unique_ptr<Modification>> infere( std::vector<Vertex>& graph, int k, bool* pSolved, bool* pSolutionExists ) //returns undo stack
{
	std::vector<std::unique_ptr<Modification>> undoStack;
	*pSolved = false;

	bool modified = true;
	while ( !(*pSolved) && modified )
	{
		modified = false;
		// constraint propagation: check all edges for coloured ends
		for ( int i = 0; i < graph.size(); ++i )
		{
			Vertex& vertex = graph[i];
			if ( vertex.colour == -1 )
				continue;
			
			// filter domains
			for ( int neighbour = 0; neighbour < vertex.neighbours.size(); ++neighbour )
			{
				Vertex& neighbourVertex = graph[vertex.neighbours[neighbour]];
				if ( neighbourVertex.colour_possible[ vertex.colour ] )
				{
					undoStack.push_back( std::unique_ptr<Modification>( new ReduceDomain( &neighbourVertex, vertex.colour ) ) );
					modified = true;
				}
			}
			// check feasilibity of assignments
			for ( int neighbour = 0; neighbour < vertex.neighbours.size(); ++neighbour )
			{
				Vertex& neighbourVertex = graph[vertex.neighbours[neighbour]];
				if ( neighbourVertex.colour == vertex.colour )
				{
					*pSolved = true;
					*pSolutionExists = false;
				}
			}
		}

		// constraint propagation: check (almost) empty domains
		for ( int i = 0; i < graph.size(); ++i )
		{
			Vertex& vertex = graph[i];
			if ( vertex.colour != -1 )
				continue;

			int domainSize = 0;
			int lastSeenOption = -1;
			for ( int c = 0; c < k; c++ )
			{
				if ( vertex.colour_possible[ c ] )
				{
					++domainSize;
					lastSeenOption = c;
				}
			}

			switch( domainSize )
			{
			case 0:
				*pSolved = true;
				*pSolutionExists = false;
				break;
			case 1:
				undoStack.push_back( std::unique_ptr<Modification>( new FixColour( &vertex, lastSeenOption ) ) );
				modified = true;
			default: ;
			}
		}
	}

	// constraint propagation: check all vertices coloured?
	if ( ! *pSolved )
	{
		bool allVerticesColoured = true;
		for ( int i = 0; i < graph.size(); ++i )
			allVerticesColoured &= !( graph[i].colour == -1 );
		if ( allVerticesColoured )
		{
			*pSolved = true;
			*pSolutionExists = true;
		}
	}

	return undoStack;
}

bool kColourableBranchAndInfere( std::vector<Vertex>& graph, int k )
{
	// infere
	bool solved = false;
	bool solutionExists = true;
	std::vector<std::unique_ptr<Modification>> undoStack = infere( graph, k, &solved, &solutionExists );
	if ( solved )
	{
		// undo change
		for ( auto it = undoStack.rbegin(); it != undoStack.rend(); ++it )
			( *it )->undo();

		return solutionExists;
	}

	// branching: select vertex
	int branchVertex = 0;
	while ( graph[branchVertex].colour != -1 )
		++branchVertex;

	// branching: try all colours
	Vertex& vertex = graph[branchVertex];
	for ( int c = 0; c < k; ++c )
	{
		// colour feasible?
		if ( !vertex.colour_possible[ c ] )
			continue;

		// branch: apply change
		FixColour colourFixed( &vertex, c );

		// if not solved: branch recursively
		bool solutionFound = kColourableBranchAndInfere( graph, k );
		if ( solutionFound )
			return true; // no need to undo

		colourFixed.undo();
	}

	// undo change
	for ( auto it = undoStack.rbegin(); it != undoStack.rend(); ++it )
		( *it )->undo();

	return false;
}

bool kColourable( std::vector<Vertex>& graph, int k )
{
	for ( auto it = graph.begin(); it != graph.end(); ++it )
		it->reset();

	return kColourableBranchAndInfere( graph, k );
}

void solve()
{
	std::vector<Vertex> graph = readInput();

	if ( kColourable( graph, 1 ) )
		cout << 1 << endl;
	else if ( kColourable( graph, 2 ) )
		cout << 2 << endl;
	else if ( kColourable( graph, 3 ) )
		cout << 3 << endl;
	else if ( kColourable( graph, 4 ) )
		cout << 4 << endl;
	else
		cout << "many" << endl;
}

int main()
{
	int runs; cin >> runs;
	for ( int run = 0; run < runs; ++run )
	{
		if ( run == 2 )
		{
			int y = 5;
		}

		solve();
	}
	return 0;
}
