/*
Tour de France solution by Stijn Duijzer.

// @EXPECTED_RESULTS@: CORRECT

Running time: O(N * 2^(N/2))
Memory usage: O(N+M)
*/

#include <iostream>
#include <vector>
using namespace std;

const int maxN = 36; // max num cities
const int maxD = 10000; // max distance per city
const int maxx = maxN*maxD+1; // max distance for entire tour
int N, M; 
int calls, tours;

struct Edge;
struct City
{
  void reset(int i);
  Edge* other(Edge* e);
  
  int id;
  vector<Edge*> out;
  vector<Edge*> in;

  // in branch algorithm
  bool chosen;
} city[maxN];

struct Edge
{
  City* from;
  City* to;
  int distance;

  // in branch algorithm
  bool impossible;
} edge[2*maxN];

void set_impossibles ( Edge* chosen, vector<Edge*>& p )
{
  if ( chosen == 0 ) return;
  
  for(int i = 1; i <= 2; i++)
  {
    Edge* e = (i==1?chosen->to:chosen->from) -> other(chosen);
    if ( e && !e->impossible )
    {
      e->impossible = true;
      p.push_back(e);
      set_impossibles(e->to->other(e),p);
      set_impossibles(e->from->other(e),p);
    }
  }
}

int f(City* c, int n, int val)
{
  calls++;
  if ( n == N ) {tours++; return val;}
 
  int best = maxx;
  for(int i = 0; i < c->out.size(); i++)
  {
    Edge* e = c->out[i];
    City* to = e->to;

    if ( e->impossible ) continue;
    if ( to->chosen ) continue;
    if ( to->id == 0 && n != N-1 ) continue;
    if ( to->id != 0 && n == N-1 ) continue;

    // pick e
    to->chosen = true;
    vector<Edge*> p;
    set_impossibles( e, p );

    int tmp = f( to, n+1, val+e->distance );
    if ( tmp < best ) { best = tmp; }

    // undo pick e
    to->chosen = false;

    // reset impossible edges
    for(int j = 0; j < p.size(); j++)
    {
      p[j]->impossible = false;
    }
  }

  return best;
}

int main()
{
	int runs, line = 1;
  cin >> runs; line++;

	for(int run = 1; run <= runs; run++)
	{
    cin >> N >> M; line++;

    // reset cities
    for(int i = 0; i < N; i++)
      city[i].reset(i);
    
    // read edges
    for(int i = 0; i < M; i++)
    {
      int from, to, d;
      cin >> from >> to >> d; line++;
      Edge* e = &edge[i];
          
      e->from = &city[from];
      e->to = &city[to];
      e->distance = d;
      e->impossible = false;
      
      city[from].out.push_back(e);
      city[to].in.push_back(e);
    }

    calls = tours = 0;
    int ans = f(&city[0], 0, 0);

    // output answer
    cout << ans << endl;
    //cout << "n:" << N << "  " << ans << " (t: " << tours << ", " << calls << " calls, line " << line << " )" << endl;
	}	

	return 0;	
}

Edge* City::other(Edge* e)
{
  vector<Edge*>* v = (e->from==this?(&out):(&in));
  if ( v->size() == 1 ) return 0;
  return (*v)[0]==e?(*v)[1]:(*v)[0];
}

void City::reset(int i)
{
  id = i;
  out.clear();
  in.clear();
  chosen = false;
}



