/*
solution for kingswalk by Stijn Duyzer

Approach:
call dT the shortest distance from start to target square.         
It is a dynamic programming with two sets:
- one (called cur) with distance d-1 from the source (and (dT-d+1) to target)
- one (called nxt), that we fill from cur, and has distance d from source (and dT-d to target)

Because the size of these sets is O(dT) we get as complexity:
Time: O(dT^2)
Memory: O(dT)
*/
#include <iostream>
#include <set>
#include <cmath>
using namespace std;

const int M = 5318008;

struct Square
{
	int x, y;
	mutable int c; // number of options
	
	Square() {};
	Square(int x_, int y_) { x = x_; y = y_; c = 0;} 
	 
	bool operator<(const Square& s) const {return x!=s.x?x<s.x:y<s.y;}     	 
	int dist(const Square& s) const	{return max(abs(x-s.x),abs(y-s.y));} 
};

int main()
{
	set<Square>::const_iterator it, it2;
	
	int runs; cin >> runs;
	for(int run = 1; run <= runs; run++)
	{
		int n, m; cin >> n; m = n; // board size
		Square s0; cin >> s0.x >> s0.y; s0.c = 1; // start square
		Square sE; cin >> sE.x >> sE.y; sE.c = 0; // target square
		
		int dT = s0.dist(sE); // total distance
		
		set< Square > cur, nxt;
		cur.insert( s0 );
		
		for ( int d = 1; d <= dT; d++ )
		{
			while( !cur.empty() )
			{
				it = cur.begin();
				
				for(int dx = -1; dx <= 1; dx++) 
				for(int dy = -1; dy <= 1; dy++)
				{
					Square t(it->x+dx,it->y+dy);
					if ( t.x <= 0 || t.x > n ) continue;
					if ( t.y <= 0 || t.y > m ) continue;
					if ( s0.dist(t) < d ) continue;
					if ( d + t.dist(sE) > dT ) continue;
					
					it2 = nxt.insert(t).first;
					it2->c += it->c;
          if ( it2->c >= M ) it2->c -= M;
				}
				
				cur.erase(it);
			}
		
			cur = nxt; nxt.clear();
		}
		
		cout << cur.find(sE)->c << endl;
	}
	
	
	return 0;
}
