// Solution to problem `Mario'
// Uses simulation to check if Mario can move from one boat to another.
// Simulation in function checkBoats moves maximum possible distance
// in same direction (hence towards left[i]/right[i] for one of the boats)
// in one step.
// Stops as soon as Mario finds a boat that can bring him to x=w.
//
// Rudy van Vliet, 15 October, 2015

#include<iostream>
#include<cstring>

using namespace std;

const int MaxN = 500;
const int MaxW = 500;

int xLeft[MaxN+1],
    xRight[MaxN+1],
    range[MaxN+1],
    firstTime[MaxN+1];
bool done1[2*MaxW+1][2][2],  // 2*MaxW, because we double the ranges
       // done1[x][dir][s]: we have seen combination of
       //   boat 1 at position x and direction dir
       //   boat 2 at side s (0=left, 1=right)
     done2[2][2*MaxW+1][2];  // 2*MaxW, because we double the ranges
       // done2[s][x][dir]: we have seen combination of
       //   boat 1 at side s (0=left, 1=right)
       //   boat 2 at position x and direction dir
int priorQ[MaxN+1];
int posInPriorQ[MaxN+1];

//*************************************************************************

bool IntegerInRange (const char *variable, int val, int minVal, int maxVal)
{
  if (val>=minVal && val<=maxVal)
    return true;
  else
  { cout << variable << "=" << val << ", but should be in [" << minVal
         << "," << maxVal << "]" << endl;
    return false;
  }

}  // IntegerInRange

//*************************************************************************

// Move boat on position pos in priorQ up to its proper position
void moveInPriorQ (int first, int pos)
{ int i, j;

  i = priorQ[pos];
  pos --;

  while (pos>=first && firstTime[priorQ[pos]]>firstTime[i])
  { j = priorQ[pos];
    priorQ[pos+1] = j;
    posInPriorQ[j] = pos+1;
    pos--;
  }

  pos++;
  priorQ[pos] = i;
  posInPriorQ[i] = pos;

}  // moveInPriorQ

//*************************************************************************

// Add boat i with time firstTime[i] to priority queue
// (insertion Sort)
void addToPriorQ (int i, int first, int &last)
{ int pos;

  last ++;
  pos = last;
  priorQ[pos] = i;
  posInPriorQ[i] = pos;
  moveInPriorQ (first, pos);

}  // addToPriorQ

//*************************************************************************

// Determine position x and direction of boat i at time t.
void determineXAndDir (int t, int i, int &x, int &dir)
{ int modt;

  modt = t % (2*range[i]);

  if (modt < range[i])
  { x = xLeft[i] + modt;
    dir = 1;
  }
  else
  { x = xRight[i] - (modt-range[i]);
    dir = 0;
  }

}  // determineXAndDir

//*************************************************************************

// Compute first time at/after time t that boat i reaches xLeft[i].
int computeTimeAtLeft (int t, int i)
{ int modt;

  modt = t % (2*range[i]);

  return (t + (2*range[i]-modt));

}  // computeTimeAtLeft

//*************************************************************************

// Compute first time at/after time t that boat i reaches xRight[i].
int computeTimeAtRight (int t, int i)
{ int modt;

  modt = t % (2*range[i]);

  if (modt <= range[i])  // boat is moving right
    return (t + (range[i]-modt));
  else  // boat is moving left
    return (t + (3*range[i]-modt));

}  // computeTimeAtRight

//*************************************************************************

// Check if Mario can move from boat i to boat j, if he can be on boat i
// at time t.
// If so, return the earliest possible time
// Otherwise, return -1
// Pre: all ranges are even, so the earliest possible time is an integer
int checkBoats (int t, int i1, int i2)
{ int x1, x2,
      dir1, dir2,  // directions of boats:
                   //   dir = 0: boat is moving left
                   //   dir = 1: boat is moving right
      s1, s2,      // s = 0: boat at left side
                   // s = 1: boat at right side
      t1, t2, newT;

  bool continueSearch;

  if (xLeft[i1]>xRight[i2] || xLeft[i2]>xRight[i1])
    // impossible to get together
    return -1;
  else
    if (range[i1]==range[i2] && xLeft[i1]!=xLeft[i2])
      // impossible to get together
      return -1;
    else  // try to get together
    {
      for (x1=xLeft[i1];x1<=xRight[i1];x1++)
        for (dir1=0;dir1<=1;dir1++)
          for (s2=0;s2<=1;s2++)
            done1 [x1][dir1][s2] = false;

      for (s1=0;s1<=1;s1++)
        for (x2=xLeft[i2];x2<=xRight[i2];x2++)
          for (dir2=0;dir2<=1;dir2++)
            done2 [s1][x2][dir2] = false;

      determineXAndDir (t, i1, x1, dir1);
      determineXAndDir (t, i2, x2, dir2);

      continueSearch = true;

        // simulate the moves of the boats
      while (x1!=x2 && continueSearch)
      {
          // compute time newT when first of two boats reaches
          // left side or right side
        if (dir1==0)  // boat is moving left
          t1 = computeTimeAtLeft (t, i1);
        else
          t1 = computeTimeAtRight (t, i1);
        if (dir2==0)  // boat is moving left
          t2 = computeTimeAtLeft (t, i2);
        else
          t2 = computeTimeAtRight (t, i2);

        if (t1<t2)
          newT = t1;
        else
          newT = t2;

        if (x1<x2 && dir1==1 && dir2==0 && 2*(newT-t)>=(x2-x1))
          // boat 1 moved right, boat 2 moved left,
          // and they have crossed each other
          newT = t + (x2-x1)/2;

        if (x1>x2 && dir1==0 && dir2==1 && 2*(newT-t)>=(x1-x2))
          // boat 1 moved left, boat 2 moved right,
          // and they have crossed each other
          newT = t + (x1-x2)/2;

        if (newT==t)  // should not occur
          cout << "newT=t!" << endl;

        t = newT;

        determineXAndDir (t, i1, x1, dir1);
        determineXAndDir (t, i2, x2, dir2);

        if (x2==xLeft[i2])
        { if (!done1[x1][dir1][0])
            done1[x1][dir1][0] = true;
          else
            continueSearch = false;
        }
        if (x2==xRight[i2])
        { if (!done1[x1][dir1][1])
            done1[x1][dir1][1] = true;
          else
            continueSearch = false;
        }
        if (x1==xLeft[i1])
        { if (!done2[0][x2][dir2])
            done2[0][x2][dir2] = true;
          else
            continueSearch = false;
        }
        if (x1==xRight[i1])
        { if (!done2[1][x2][dir2])
            done2[1][x2][dir2] = true;
          else
            continueSearch = false;
        }

      }  // while

      if (x1==x2)
        return t;
      else
        return -1;
    }

}  // checkBoats

//*************************************************************************

int main()
{ int nInst, inst;
  int N, W,
      i, j,
      timeAtW,
      first, last,
      t, t2;
  bool OK;

  cin >> nInst;
  for (inst=1;inst<=nInst;inst++)
  { cin >> N >> W;

    OK = true;
    if (IntegerInRange("N", N, 0, MaxN) &&
        IntegerInRange("W", W, 1, MaxW))
    { for (i=1;i<=N;i++)
      { cin >> xLeft[i] >> xRight[i];
        if (!IntegerInRange("xLeft[i]", xLeft[i], 0, W-1) ||
            !IntegerInRange("xRight[i]", xRight[i], xLeft[i]+1, W))
          OK = false;
      }
    }
    else  // N and/or W are out of range, so read (but do not process)
          // remaining input
    { for (i=1;i<=N;i++)
        cin >> xLeft[0] >> xRight[0];
      OK = false;
    }
   
    if (OK)
    {
        // double all ranges, to make sure you can step from one boat to
        // another at an integer time
      W *= 2;
      for (i=1;i<=N;i++)
      { xLeft[i] *= 2;
        xRight[i] *= 2;
        range[i] = xRight[i] - xLeft[i];
      }

      timeAtW = -1;

      first = 0;
      last = -1;
      for (i=1;i<=N;i++)
      { if (xLeft[i]==0)
        { firstTime[i] = 0;
          addToPriorQ (i, first, last);
          if (xRight[i]==W)
            timeAtW = W;
        }
        else
        { firstTime[i] = -1;  // default value
          posInPriorQ[i] = -1;
        }
      }

      if (timeAtW==-1)  // go searching
      { while (last>=first && timeAtW==-1)
        {  // priorQ is not empty, and x=w cannot be reached yet
          i = priorQ[first];
          first ++;

          for (j=1;j<=N && timeAtW==-1;j++)
          { if (j!=i && (firstTime[j]==-1 || firstTime[i]<firstTime[j]))
            { t = checkBoats (firstTime[i], i, j);

              if (t!=-1)  // it is possible to move to boat j
              { if (firstTime[j]==-1)  // first time we can move to boat j
                { firstTime[j] = t;
                  addToPriorQ (j, first, last);
                  if (xRight[j]==W)
                  { t2 = computeTimeAtRight (t, j);
                    if (timeAtW==-1 || t2<timeAtW)
                      timeAtW = t2;
                  }
                }
                else  // firstTime[j]>firstTime[i], so j is in priorQ already
                { if (t<firstTime[j])
                  { firstTime[j] = t;
                    moveInPriorQ (first, posInPriorQ[j]);
                    if (xRight[j]==W)
                    { t2 = computeTimeAtRight (t, j);
                      if (timeAtW==-1 || t2<timeAtW)
                        timeAtW = t2;
                    }
                  }
                }
              }  // t!=-1

            }  // j!=i
              
          }  // for

        }  // while
      }  // if

      if (timeAtW==-1)
        cout << "IMPOSSIBLE" << endl;
      else
        cout << (timeAtW/2) << endl;  // because we doubled all ranges

    }  // input OK

  }

  return 0;
}
